==> academy-user-core-2.1.12-sources.jar: com/ptteng/academy/user/model/CooperatorUserStatistics.java <==
package com.ptteng.academy.user.model;

import java.io.Serializable;

public class CooperatorUserStatistics implements Serializable {
    private static final long serialVersionUID = 5339042744866816L;

    private Long id;
    private double totalMoney;
    private int lessonOrderNumber;
    private int memberOrderNumber;
    private int totalOrderNumber;
    private String type;
    private String mobile;
    private String username;
    private Integer status;
    private String name;


    @Override
    public String toString() {
        return "CooperatorUserStatistics{" +
                "id=" + id +
                ", totalMoney=" + totalMoney +
                ", lessonOrderNumber=" + lessonOrderNumber +
                ", memberOrderNumber=" + memberOrderNumber +
                ", totalOrderNumber=" + totalOrderNumber +
                ", type='" + type + '\'' +
                ", mobile='" + mobile + '\'' +
                ", username='" + username + '\'' +
                ", status=" + status +
                ", name='" + name + '\'' +
                '}';
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public double getTotalMoney() {
        return totalMoney;
    }

    public void setTotalMoney(double totalMoney) {
        this.totalMoney = totalMoney;
    }

    public int getLessonOrderNumber() {
        return lessonOrderNumber;
    }

    public void setLessonOrderNumber(int lessonOrderNumber) {
        this.lessonOrderNumber = lessonOrderNumber;
    }

    public int getMemberOrderNumber() {
        return memberOrderNumber;
    }

    public void setMemberOrderNumber(int memberOrderNumber) {
        this.memberOrderNumber = memberOrderNumber;
    }

    public int getTotalOrderNumber() {
        return totalOrderNumber;
    }

    public void setTotalOrderNumber(int totalOrderNumber) {
        this.totalOrderNumber = totalOrderNumber;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public String getUsername() {
        return username;
    }

    public void setUsername(String username) {
        this.username = username;
    }
}

==> academy-user-core-2.3.4-sources.jar: com/ptteng/academy/user/model/CooperatorUserStatistics.java <==
package com.ptteng.academy.user.model;

import java.io.Serializable;

public class CooperatorUserStatistics implements Serializable {
    private static final long serialVersionUID = 5339042744866816L;

    private Long id;
    private double totalMoney;
    private int lessonOrderNumber;
    private int memberOrderNumber;
    private int totalOrderNumber;
    private String type;
    private String mobile;
    private String username;
    private Integer status;
    private String name;
    private String alias;
    private String userMobile;


    @Override
    public String toString() {
        return "CooperatorUserStatistics{" +
                "id=" + id +
                ", totalMoney=" + totalMoney +
                ", lessonOrderNumber=" + lessonOrderNumber +
                ", memberOrderNumber=" + memberOrderNumber +
                ", totalOrderNumber=" + totalOrderNumber +
                ", type='" + type + '\'' +
                ", mobile='" + mobile + '\'' +
                ", username='" + username + '\'' +
                ", status=" + status +
                ", name='" + name + '\'' +
                ", alias='" + alias + '\'' +
                ", userMobile='" + userMobile + '\'' +
                '}';
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public double getTotalMoney() {
        return totalMoney;
    }

    public void setTotalMoney(double totalMoney) {
        this.totalMoney = totalMoney;
    }

    public int getLessonOrderNumber() {
        return lessonOrderNumber;
    }

    public void setLessonOrderNumber(int lessonOrderNumber) {
        this.lessonOrderNumber = lessonOrderNumber;
    }

    public int getMemberOrderNumber() {
        return memberOrderNumber;
    }

    public void setMemberOrderNumber(int memberOrderNumber) {
        this.memberOrderNumber = memberOrderNumber;
    }

    public int getTotalOrderNumber() {
        return totalOrderNumber;
    }

    public void setTotalOrderNumber(int totalOrderNumber) {
        this.totalOrderNumber = totalOrderNumber;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public String getUsername() {
        return username;
    }

    public void setUsername(String username) {
        this.username = username;
    }

    public String getAlias() {
        return alias;
    }

    public void setAlias(String alias) {
        this.alias = alias;
    }

    public String getUserMobile() {
        return userMobile;
    }

    public void setUserMobile(String userMobile) {
        this.userMobile = userMobile;
    }
}
